==> kubernetes-model-admissionregistration-4.13.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/ValidatingWebhookFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

public interface ValidatingWebhookFluent<A extends io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookFluent<A>> extends Fluent<A> {


    public A addToAdmissionReviewVersions(int index,String item);
    public A setToAdmissionReviewVersions(int index,String item);
    public A addToAdmissionReviewVersions(String... items);
    public A addAllToAdmissionReviewVersions(Collection<String> items);
    public A removeFromAdmissionReviewVersions(String... items);
    public A removeAllFromAdmissionReviewVersions(Collection<String> items);
    public List<String> getAdmissionReviewVersions();
    public String getAdmissionReviewVersion(int index);
    public String getFirstAdmissionReviewVersion();
    public String getLastAdmissionReviewVersion();
    public String getMatchingAdmissionReviewVersion(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingAdmissionReviewVersion(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withAdmissionReviewVersions(List<String> admissionReviewVersions);
    public A withAdmissionReviewVersions(String... admissionReviewVersions);
    public Boolean hasAdmissionReviewVersions();
    public A addNewAdmissionReviewVersion(String arg1);
    public A addNewAdmissionReviewVersion(StringBuilder arg1);
    public A addNewAdmissionReviewVersion(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildClientConfig instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfig getClientConfig();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfig buildClientConfig();
    public A withClientConfig(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfig clientConfig);
    public Boolean hasClientConfig();
    public ValidatingWebhookFluent.ClientConfigNested<A> withNewClientConfig();
    public ValidatingWebhookFluent.ClientConfigNested<A> withNewClientConfigLike(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfig item);
    public ValidatingWebhookFluent.ClientConfigNested<A> editClientConfig();
    public ValidatingWebhookFluent.ClientConfigNested<A> editOrNewClientConfig();
    public ValidatingWebhookFluent.ClientConfigNested<A> editOrNewClientConfigLike(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfig item);
    public String getFailurePolicy();
    public A withFailurePolicy(String failurePolicy);
    public Boolean hasFailurePolicy();
    public A withNewFailurePolicy(String arg1);
    public A withNewFailurePolicy(StringBuilder arg1);
    public A withNewFailurePolicy(StringBuffer arg1);
    public String getMatchPolicy();
    public A withMatchPolicy(String matchPolicy);
    public Boolean hasMatchPolicy();
    public A withNewMatchPolicy(String arg1);
    public A withNewMatchPolicy(StringBuilder arg1);
    public A withNewMatchPolicy(StringBuffer arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildNamespaceSelector instead.
 * @return The buildable object.
 */
@Deprecated public LabelSelector getNamespaceSelector();
    public LabelSelector buildNamespaceSelector();
    public A withNamespaceSelector(LabelSelector namespaceSelector);
    public Boolean hasNamespaceSelector();
    public ValidatingWebhookFluent.NamespaceSelectorNested<A> withNewNamespaceSelector();
    public ValidatingWebhookFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(LabelSelector item);
    public ValidatingWebhookFluent.NamespaceSelectorNested<A> editNamespaceSelector();
    public ValidatingWebhookFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector();
    public ValidatingWebhookFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(LabelSelector item);
    
/**
 * This method has been deprecated, please use method buildObjectSelector instead.
 * @return The buildable object.
 */
@Deprecated public LabelSelector getObjectSelector();
    public LabelSelector buildObjectSelector();
    public A withObjectSelector(LabelSelector objectSelector);
    public Boolean hasObjectSelector();
    public ValidatingWebhookFluent.ObjectSelectorNested<A> withNewObjectSelector();
    public ValidatingWebhookFluent.ObjectSelectorNested<A> withNewObjectSelectorLike(LabelSelector item);
    public ValidatingWebhookFluent.ObjectSelectorNested<A> editObjectSelector();
    public ValidatingWebhookFluent.ObjectSelectorNested<A> editOrNewObjectSelector();
    public ValidatingWebhookFluent.ObjectSelectorNested<A> editOrNewObjectSelectorLike(LabelSelector item);
    public A addToRules(int index,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations item);
    public A setToRules(int index,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations item);
    public A addToRules(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations... items);
    public A addAllToRules(Collection<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations> items);
    public A removeFromRules(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations... items);
    public A removeAllFromRules(Collection<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations> items);
    public A removeMatchingFromRules(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperationsBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations> getRules();
    public List<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations> buildRules();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations buildRule(int index);
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations buildFirstRule();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations buildLastRule();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations buildMatchingRule(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperationsBuilder> predicate);
    public Boolean hasMatchingRule(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperationsBuilder> predicate);
    public A withRules(List<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations> rules);
    public A withRules(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations... rules);
    public Boolean hasRules();
    public ValidatingWebhookFluent.RulesNested<A> addNewRule();
    public ValidatingWebhookFluent.RulesNested<A> addNewRuleLike(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations item);
    public ValidatingWebhookFluent.RulesNested<A> setNewRuleLike(int index,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations item);
    public ValidatingWebhookFluent.RulesNested<A> editRule(int index);
    public ValidatingWebhookFluent.RulesNested<A> editFirstRule();
    public ValidatingWebhookFluent.RulesNested<A> editLastRule();
    public ValidatingWebhookFluent.RulesNested<A> editMatchingRule(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperationsBuilder> predicate);
    public String getSideEffects();
    public A withSideEffects(String sideEffects);
    public Boolean hasSideEffects();
    public A withNewSideEffects(String arg1);
    public A withNewSideEffects(StringBuilder arg1);
    public A withNewSideEffects(StringBuffer arg1);
    public Integer getTimeoutSeconds();
    public A withTimeoutSeconds(Integer timeoutSeconds);
    public Boolean hasTimeoutSeconds();
    public interface ClientConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfigFluent<ValidatingWebhookFluent.ClientConfigNested<N>> {

        public N and();
        public N endClientConfig();    }


    public interface NamespaceSelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LabelSelectorFluent<ValidatingWebhookFluent.NamespaceSelectorNested<N>> {

        public N and();
        public N endNamespaceSelector();    }


    public interface ObjectSelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LabelSelectorFluent<ValidatingWebhookFluent.ObjectSelectorNested<N>> {

        public N and();
        public N endObjectSelector();    }


    public interface RulesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperationsFluent<ValidatingWebhookFluent.RulesNested<N>> {

        public N and();
        public N endRule();    }


}

==> kubernetes-model-admissionregistration-5.0.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/ValidatingWebhookFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

public interface ValidatingWebhookFluent<A extends io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookFluent<A>> extends Fluent<A> {


    public A addToAdmissionReviewVersions(int index,String item);
    public A setToAdmissionReviewVersions(int index,String item);
    public A addToAdmissionReviewVersions(String... items);
    public A addAllToAdmissionReviewVersions(Collection<String> items);
    public A removeFromAdmissionReviewVersions(String... items);
    public A removeAllFromAdmissionReviewVersions(Collection<String> items);
    public List<String> getAdmissionReviewVersions();
    public String getAdmissionReviewVersion(int index);
    public String getFirstAdmissionReviewVersion();
    public String getLastAdmissionReviewVersion();
    public String getMatchingAdmissionReviewVersion(Predicate<String> predicate);
    public Boolean hasMatchingAdmissionReviewVersion(Predicate<String> predicate);
    public A withAdmissionReviewVersions(List<String> admissionReviewVersions);
    public A withAdmissionReviewVersions(String... admissionReviewVersions);
    public Boolean hasAdmissionReviewVersions();
    public A addNewAdmissionReviewVersion(String arg1);
    public A addNewAdmissionReviewVersion(StringBuilder arg1);
    public A addNewAdmissionReviewVersion(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildClientConfig instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfig getClientConfig();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfig buildClientConfig();
    public A withClientConfig(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfig clientConfig);
    public Boolean hasClientConfig();
    public ValidatingWebhookFluent.ClientConfigNested<A> withNewClientConfig();
    public ValidatingWebhookFluent.ClientConfigNested<A> withNewClientConfigLike(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfig item);
    public ValidatingWebhookFluent.ClientConfigNested<A> editClientConfig();
    public ValidatingWebhookFluent.ClientConfigNested<A> editOrNewClientConfig();
    public ValidatingWebhookFluent.ClientConfigNested<A> editOrNewClientConfigLike(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfig item);
    public String getFailurePolicy();
    public A withFailurePolicy(String failurePolicy);
    public Boolean hasFailurePolicy();
    public A withNewFailurePolicy(String arg1);
    public A withNewFailurePolicy(StringBuilder arg1);
    public A withNewFailurePolicy(StringBuffer arg1);
    public String getMatchPolicy();
    public A withMatchPolicy(String matchPolicy);
    public Boolean hasMatchPolicy();
    public A withNewMatchPolicy(String arg1);
    public A withNewMatchPolicy(StringBuilder arg1);
    public A withNewMatchPolicy(StringBuffer arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildNamespaceSelector instead.
 * @return The buildable object.
 */
@Deprecated public LabelSelector getNamespaceSelector();
    public LabelSelector buildNamespaceSelector();
    public A withNamespaceSelector(LabelSelector namespaceSelector);
    public Boolean hasNamespaceSelector();
    public ValidatingWebhookFluent.NamespaceSelectorNested<A> withNewNamespaceSelector();
    public ValidatingWebhookFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(LabelSelector item);
    public ValidatingWebhookFluent.NamespaceSelectorNested<A> editNamespaceSelector();
    public ValidatingWebhookFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector();
    public ValidatingWebhookFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(LabelSelector item);
    
/**
 * This method has been deprecated, please use method buildObjectSelector instead.
 * @return The buildable object.
 */
@Deprecated public LabelSelector getObjectSelector();
    public LabelSelector buildObjectSelector();
    public A withObjectSelector(LabelSelector objectSelector);
    public Boolean hasObjectSelector();
    public ValidatingWebhookFluent.ObjectSelectorNested<A> withNewObjectSelector();
    public ValidatingWebhookFluent.ObjectSelectorNested<A> withNewObjectSelectorLike(LabelSelector item);
    public ValidatingWebhookFluent.ObjectSelectorNested<A> editObjectSelector();
    public ValidatingWebhookFluent.ObjectSelectorNested<A> editOrNewObjectSelector();
    public ValidatingWebhookFluent.ObjectSelectorNested<A> editOrNewObjectSelectorLike(LabelSelector item);
    public A addToRules(int index,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations item);
    public A setToRules(int index,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations item);
    public A addToRules(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations... items);
    public A addAllToRules(Collection<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations> items);
    public A removeFromRules(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations... items);
    public A removeAllFromRules(Collection<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations> items);
    public A removeMatchingFromRules(Predicate<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperationsBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations> getRules();
    public List<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations> buildRules();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations buildRule(int index);
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations buildFirstRule();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations buildLastRule();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations buildMatchingRule(Predicate<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperationsBuilder> predicate);
    public Boolean hasMatchingRule(Predicate<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperationsBuilder> predicate);
    public A withRules(List<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations> rules);
    public A withRules(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations... rules);
    public Boolean hasRules();
    public ValidatingWebhookFluent.RulesNested<A> addNewRule();
    public ValidatingWebhookFluent.RulesNested<A> addNewRuleLike(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations item);
    public ValidatingWebhookFluent.RulesNested<A> setNewRuleLike(int index,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperations item);
    public ValidatingWebhookFluent.RulesNested<A> editRule(int index);
    public ValidatingWebhookFluent.RulesNested<A> editFirstRule();
    public ValidatingWebhookFluent.RulesNested<A> editLastRule();
    public ValidatingWebhookFluent.RulesNested<A> editMatchingRule(Predicate<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperationsBuilder> predicate);
    public String getSideEffects();
    public A withSideEffects(String sideEffects);
    public Boolean hasSideEffects();
    public A withNewSideEffects(String arg1);
    public A withNewSideEffects(StringBuilder arg1);
    public A withNewSideEffects(StringBuffer arg1);
    public Integer getTimeoutSeconds();
    public A withTimeoutSeconds(Integer timeoutSeconds);
    public Boolean hasTimeoutSeconds();
    public interface ClientConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfigFluent<ValidatingWebhookFluent.ClientConfigNested<N>> {

        public N and();
        public N endClientConfig();    }


    public interface NamespaceSelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LabelSelectorFluent<ValidatingWebhookFluent.NamespaceSelectorNested<N>> {

        public N and();
        public N endNamespaceSelector();    }


    public interface ObjectSelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LabelSelectorFluent<ValidatingWebhookFluent.ObjectSelectorNested<N>> {

        public N and();
        public N endObjectSelector();    }


    public interface RulesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.RuleWithOperationsFluent<ValidatingWebhookFluent.RulesNested<N>> {

        public N and();
        public N endRule();    }


}
